aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/report_content.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/report_content.h')
-rw-r--r--lib/csapi/report_content.h52
1 files changed, 28 insertions, 24 deletions
diff --git a/lib/csapi/report_content.h b/lib/csapi/report_content.h
index a20c6838..c86a4301 100644
--- a/lib/csapi/report_content.h
+++ b/lib/csapi/report_content.h
@@ -4,32 +4,36 @@
#pragma once
+#include "converters.h"
+
#include "jobs/basejob.h"
-#include "converters.h"
+namespace Quotient
+{
+
+// Operations
-namespace QMatrixClient
+/// Reports an event as inappropriate.
+/*!
+ * Reports an event as inappropriate to the server, which may then notify
+ * the appropriate people.
+ */
+class ReportContentJob : public BaseJob
{
- // Operations
+public:
+ /*! Reports an event as inappropriate.
+ * \param roomId
+ * The room in which the event being reported is located.
+ * \param eventId
+ * The event to report.
+ * \param score
+ * The score to rate this content as where -100 is most offensive
+ * and 0 is inoffensive.
+ * \param reason
+ * The reason the content is being reported. May be blank.
+ */
+ explicit ReportContentJob(const QString& roomId, const QString& eventId,
+ int score, const QString& reason);
+};
- /// Reports an event as inappropriate.
- ///
- /// Reports an event as inappropriate to the server, which may then notify
- /// the appropriate people.
- class ReportContentJob : public BaseJob
- {
- public:
- /*! Reports an event as inappropriate.
- * \param roomId
- * The room in which the event being reported is located.
- * \param eventId
- * The event to report.
- * \param score
- * The score to rate this content as where -100 is most offensive
- * and 0 is inoffensive.
- * \param reason
- * The reason the content is being reported. May be blank.
- */
- explicit ReportContentJob(const QString& roomId, const QString& eventId, int score, const QString& reason);
- };
-} // namespace QMatrixClient
+} // namespace Quotient